@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2018 by the individuals mentioned in the source code history
+#   Copyright 2007-2019 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -45,6 +45,11 @@ vechs <- function(x) {
 	return(x[lower.tri(x, diag=FALSE)])
 }
 
+'vechs<-' <- function(x, value) {
+	x[lower.tri(x, diag=FALSE)] <- value
+	x
+}
+
 diag2vec <- function(x) {
 	return(as.matrix(diag(as.matrix(x))))
 }
