@@ -31,7 +31,7 @@
 #--------------------------------------
 # Needed packages
 
-
+library(testthat)
 require(OpenMx)
 data(Bollen)
 
@@ -142,6 +142,12 @@ fitParam <- c(mxEval(Lam, wlsRun)[1:4,1], diag(mxEval(Theta, wlsRun)))
 
 omxCheckCloseEnough(bollenParam, fitParam, epsilon=0.01)
 
+j1 <- expect_warning(omxManifestModelByParameterJacobian(wlsRun, standardize = TRUE),
+                     "Means requested, but model has no means")
+# Tedious to check all entries, but if variances match then
+# other labels are probably correct.
+expect_equivalent(j1[1:8, paste0('var',1:8)], diag(8))
+
 #--------------------------------------
 # Marginals should be fairly close to cumulants
 
