@@ -64,7 +64,7 @@ m2 <- mxModel(model="sleep", type="RAM", manifestVars=c("Reaction"), latentVars
 
 omxCheckError(mxModel(m2, mxPath('by_Subject.intercept', 'Reaction',
                    values=1, free=FALSE, joinKey="Subject")),
-              "Nice try. You need to create an upper level RAM model called 'by_Subject' and add it as a submodel of 'sleep' before you can create paths between these models.")
+              "You need to create an upper level RAM model called 'by_Subject' and add it as a submodel of 'sleep' before you can create paths between these models.")
 
 bySub <- mxModel(
   model="by_Subject", type="RAM",
@@ -85,15 +85,15 @@ omxCheckError(mxModel(m2, mxPath('intercept', 'Reaction',
 
 omxCheckError(mxModel(m2, mxPath(c('Bathtub.intercept', 'Sink.intercept'), 'Reaction',
                                  values=1, free=FALSE, joinKey="Subject")),
-              "Nice try. You need to create an upper level RAM model called 'Bathtub' and add it as a submodel of 'sleep' before you can create paths between these models.")
+              "You need to create an upper level RAM model called 'Bathtub' and add it as a submodel of 'sleep' before you can create paths between these models.")
 
 omxCheckError(mxModel(m2, mxPath('by_Subject.intersept', 'Reaction',
                                  values=1, free=FALSE, joinKey="Subject")),
-              "Nice try, you need to add 'intersept' to either manifestVars or latentVars in model 'by_Subject' before you can use them in a path.")
+              "You need to add 'intersept' to either manifestVars or latentVars in model 'by_Subject' before you can use them in a path.")
 
 omxCheckError(mxModel(m2, mxPath('by_Subject.intercept', 'React',
                                  values=1, free=FALSE, joinKey="Subject")),
-              "Nice try, you need to add 'React' to either manifestVars or latentVars before you can use them in a path.")
+              "You need to add 'React' to either manifestVars or latentVars before you can use them in a path.")
 
 m2 <- mxModel(m2,
               mxPath('by_Subject.intercept', 'Reaction',
