@@ -150,11 +150,11 @@ void omxCopyMatrix(omxMatrix *dest, omxMatrix *orig) {
 
 	if(dest->rows == 0 || dest->cols == 0) {
 		omxFreeInternalMatrixData(dest);
-		dest->data = NULL;
+		dest->setData(0);
 	} else {
 		if(regenerateMemory) {
 			omxFreeInternalMatrixData(dest);											// Free and regenerate memory
-			dest->data = (double*) Calloc(dest->rows * dest->cols, double);
+			dest->setData((double*) Calloc(dest->rows * dest->cols, double));
 		}
 		if (dest->data != orig->data) {  // if equal then programmer mxThrow? TODO
 			memcpy(dest->data, orig->data, dest->rows * dest->cols * sizeof(double));
@@ -164,6 +164,12 @@ void omxCopyMatrix(omxMatrix *dest, omxMatrix *orig) {
 	omxMatrixLeadingLagging(dest);
 }
 
+void omxMatrix::setData(double *ptr)
+{
+	if (allocationLock) mxThrow("Cannot change allocation of matrix '%s'", name());
+	data = ptr;
+}
+
 void omxMatrix::take(omxMatrix *orig)
 {
 	omxFreeInternalMatrixData(this);
@@ -173,7 +179,7 @@ void omxMatrix::take(omxMatrix *orig)
 	this->colMajor = orig->colMajor;
 	this->populate = orig->populate;
 
-	this->data = orig->data;
+	setData(orig->data);
 	this->owner = orig->owner;
 	orig->data = 0;
 	orig->owner = 0;
@@ -292,14 +298,14 @@ int omxMatrix::lookupColumnByName(const char *target)
 void omxResizeMatrix(omxMatrix *om, int nrows, int ncols)
 {
 	// Always Recompute() before you Resize().
-	if(OMX_DEBUG_MATRIX) { 
+	if(OMX_DEBUG) { 
 		mxLog("Resizing matrix from (%d, %d) to (%d, %d)",
 			om->rows, om->cols, nrows, ncols);
 	}
 
 	if( (om->rows != nrows || om->cols != ncols)) {
 		omxFreeInternalMatrixData(om);
-		om->data = (double*) Calloc(nrows * ncols, double);
+		om->setData((double*) Calloc(nrows * ncols, double));
 	}
 
 	om->rows = nrows;
@@ -517,7 +523,7 @@ void omxMatrix::unshareMemoryWithR()
 
 	double *copy = (double*) Realloc(NULL, rows * cols, double);
 	memcpy(copy, data, rows * cols * sizeof(double));
-	data = copy;
+	setData(copy);
 	owner = NULL;
 }
 
@@ -551,7 +557,7 @@ void omxToggleRowColumnMajor(omxMatrix *mat) {
 	}
 
 	omxFreeInternalMatrixData(mat);
-	mat->data = newdata;
+	mat->setData(newdata);  // can probably avoid this, if needed
 	mat->colMajor = !mat->colMajor;
 }
 
@@ -737,12 +743,12 @@ void omxRecompute(omxMatrix *matrix, FitContext *fc)
 	int want = matrix->currentState->getWantStage();
 	matrix->omxPopulateSubstitutions(want, fc); // could be an algebra!
 
-	if(!omxNeedsUpdate(matrix)) /* do nothing */;
-	else if(matrix->algebra) omxAlgebraRecompute(matrix, want, fc);
-	else if(matrix->fitFunction != NULL) {
+	if(!omxNeedsUpdate(matrix)) return;
+
+	if(matrix->algebra) omxAlgebraRecompute(matrix, want, fc);
+	else if(matrix->fitFunction) {
 		omxFitFunctionCompute(matrix->fitFunction, want, fc);
 	}
-
 	if (want & FF_COMPUTE_FIT) {
 		omxMarkClean(matrix);
 	}
@@ -778,7 +784,7 @@ void MatrixInvert1(omxMatrix *target)
  * omxMatrix *I				: Identity matrix. Will not be changed on exit. MxM.
  */
 
-void omxShallowInverse(FitContext *fc, int numIters, omxMatrix* A, omxMatrix* Z, omxMatrix* Ax, omxMatrix* I )
+void omxShallowInverse(int numIters, omxMatrix* A, omxMatrix* Z, omxMatrix* Ax, omxMatrix* I )
 {
 	omxMatrix* origZ = Z;
     double oned = 1, minusOned = -1.0;
@@ -827,7 +833,7 @@ void omxShallowInverse(FitContext *fc, int numIters, omxMatrix* A, omxMatrix* Z,
 			omxCopyMatrix(Ax, I);
 			// F77_CALL(omxunsafedgemm)(A->majority, A->majority, &(Z->cols), &(Z->rows), &(A->rows), &oned, Z->data, &(Z->cols), A->data, &(A->cols), &oned, Ax->data, &(Ax->cols));  // Ax = Z %*% A + I
 			omxDGEMM(FALSE, FALSE, oned, A, Z, oned, Ax);
-			omxMatrix* m = Z; Z = Ax; Ax = m;	// Juggle to make Z equal to Ax
+			std::swap(Z, Ax);
 			//omxPrint(Z, "Z");
 		}
 		if(origZ != Z) { 	// Juggling has caused Ax and Z to swap
